# ImGui Bundle
[ImGui Bundle](https://github.com/pthom/imgui_bundle) is a bundle for [Dear ImGui](https://github.com/ocornut/imgui.git), including various useful libraries from its ecosystem.
It enables to easily create ImGui applications in C++, as well as in Python.

The python bindings were autogenerated from the original C++ code, so that they are easier to keep up to date, and the python API closely matches the C++ api, making it possible to easily port research code from Python to C++.


<table>
<tr>
    <td> <img src="https://traineq.org/imgui_bundle_doc/heart.gif"> </td>
    <td>  
      <b>Python</b><br>
      <img src="https://traineq.org/imgui_bundle_doc/heart_code.png" width="350"><br>
      <b>C++</b><br>
      <img src="https://traineq.org/imgui_bundle_doc/heart_code_cpp.png" width="350"><br>
    </td> 
</tr>
</table>


## Batteries included
ImGui Bundle include:
* [imgui](https://github.com/ocornut/imgui.git) : Immediate Gui library
* [hello imgui](https://github.com/pthom/hello_imgui.git): multiplatform backend provider for imgui.
* [implot](https://github.com/epezent/implot): plotting library based on ImGui
* [ImGuiColorTextEdit](external/ImGuiColorTextEdit): Colorizing text editor
* [imgui-node-editor](https://github.com/thedmd/imgui-node-editor): Node editor
* [imgui-knobs](https://github.com/altschuler/imgui-knobs): Knobs for ImGui
* [ImFileDialog](https://github.com/pthom/ImFileDialog.git): File dialogs 
* [imgui_md (markdown)](https://github.com/mekhontsev/imgui_md.git): Markdown for ImGui
* [imspinner](https://github.com/dalerank/imspinner): Spinners 

## Philosophy
* Closely mirrors the original API of ImGui and other libraries
* Original code documentation is consciously kept inside the python stubs. See for example the documentation for:
    * [imgui](https://github.com/pthom/imgui_bundle/blob/main/bindings/imgui_bundle/imgui.pyi)
    * [implot](https://github.com/pthom/imgui_bundle/blob/main/bindings/imgui_bundle/implot.pyi)
    * [hello imgui](https://github.com/pthom/imgui_bundle/blob/main/bindings/imgui_bundle/hello_imgui.pyi)
* Fully typed bindings, so that code completion works like a charm


## ImGui Backend

ImGui Bundle uses [Hello ImGui](https://github.com/pthom/hello_imgui), which is configured to use GLFW + OpenGL3.
Under C++, this is configurable (see Hello ImGui docs), with some adaptations inside on the [cmake side](cmake/add_hello_imgui.cmake).

# Usage with Python

## Install

````bash
# Install from pypi
pip install imgui-bundle

# or install from clone
git clone https://github.com/pthom/imgui_bundle.git
````

## Demo

````bash
# imgui_bundle_demo will run the demo shown below. 
# It also acts as a manual for ImGui Bundle with lots of examples and related code source.
imgui_bundle_demo 
````

<img src="https://traineq.org/imgui_bundle_doc/demo_bundle.gif">

The source for the demos can be found inside [bindings/imgui_bundle/demos](bindings/imgui_bundle/demos).

# Usage with C++

````
git clone https://github.com/pthom/imgui_bundle.git
````

Then, take inspiration from [demos_cpp/haiku_implot_heart](demos_cpp/haiku_implot_heart).
